@@ -1,11 +1,9 @@
 package HTTP::Daemon;
 
-# $Id: Daemon.pm,v 1.32 2003/10/23 19:11:32 uid39246 Exp $
-
 use strict;
 use vars qw($VERSION @ISA $PROTO $DEBUG);
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.32 $ =~ /(\d+)\.(\d+)/);
+$VERSION = "5.810";
 
 use IO::Socket qw(AF_INET INADDR_ANY inet_ntoa);
 @ISA=qw(IO::Socket::INET);
@@ -40,7 +38,7 @@ sub accept
 sub url
 {
     my $self = shift;
-    my $url = "http://";
+    my $url = $self->_default_scheme . "://";
     my $addr = $self->sockaddr;
     if (!$addr || $addr eq INADDR_ANY) {
  	require Sys::Hostname;
@@ -50,12 +48,22 @@ sub url
 	$url .= gethostbyaddr($addr, AF_INET) || inet_ntoa($addr);
     }
     my $port = $self->sockport;
-    $url .= ":$port" if $port != 80;
+    $url .= ":$port" if $port != $self->_default_port;
     $url .= "/";
     $url;
 }
 
 
+sub _default_port {
+    80;
+}
+
+
+sub _default_scheme {
+    "http";
+}
+
+
 sub product_tokens
 {
     "libwww-perl-daemon/$HTTP::Daemon::VERSION";
@@ -140,6 +148,7 @@ sub get_request
     my $r = HTTP::Request->new($method, $uri);
     $r->protocol($proto);
     ${*$self}{'httpd_client_proto'} = $proto = _http_version($proto);
+    ${*$self}{'httpd_head'} = ($method eq "HEAD");
 
     if ($proto >= $HTTP_1_0) {
 	# we expect to find some headers
@@ -181,6 +190,18 @@ sub get_request
     my $ct  = $r->header('Content-Type');
     my $len = $r->header('Content-Length');
 
+    # Act on the Expect header, if it's there
+    for my $e ( $r->header('Expect') ) {
+        if( lc($e) eq '100-continue' ) {
+            $self->send_status_line(100);
+        }
+        else {
+            $self->send_error(417);
+            $self->reason("Unsupported Expect header value");
+            return;
+        }
+    }
+
     if ($te && lc($te) eq 'chunked') {
 	# Handle chunked transfer encoding
 	my $body = "";
@@ -365,6 +386,12 @@ sub force_last_request
     ${*$self}{'httpd_nomore'}++;
 }
 
+sub head_request
+{
+    my $self = shift;
+    ${*$self}{'httpd_head'};
+}
+
 
 sub send_status_line
 {
@@ -430,11 +457,15 @@ sub send_response
 	}
 	else {
 	    $self->force_last_request;
+            $res->header('connection','close'); 
 	}
 	print $self $res->headers_as_string($CRLF);
 	print $self $CRLF;  # separates headers and content
     }
-    if (ref($content) eq "CODE") {
+    if ($self->head_request) {
+	# no content
+    }
+    elsif (ref($content) eq "CODE") {
 	while (1) {
 	    my $chunk = &$content();
 	    last unless defined($chunk) && length($chunk);
@@ -468,7 +499,7 @@ sub send_redirect
 	print $self "Content-Type: $ct$CRLF";
     }
     print $self $CRLF;
-    print $self $content if $content;
+    print $self $content if $content && !$self->head_request;
     $self->force_last_request;  # no use keeping the connection open
 }
 
@@ -491,7 +522,7 @@ EOT
 	print $self "Content-Length: " . length($mess) . $CRLF;
         print $self $CRLF;
     }
-    print $self $mess;
+    print $self $mess unless $self->head_request;
     $status;
 }
 
@@ -518,7 +549,7 @@ sub send_file_response
 	    print $self "Last-Modified: ", time2str($mtime), "$CRLF" if $mtime;
 	    print $self $CRLF;
 	}
-	$self->send_file(\*F);
+	$self->send_file(\*F) unless $self->head_request;
 	return RC_OK;
     }
     else {
@@ -584,7 +615,7 @@ HTTP::Daemon - a simple http server class
   while (my $c = $d->accept) {
       while (my $r = $c->get_request) {
 	  if ($r->method eq 'GET' and $r->url->path eq "/xyzzy") {
-              # remember, this is *not* recommened practice :-)
+              # remember, this is *not* recommended practice :-)
 	      $c->send_file_response("/etc/passwd");
 	  }
 	  else {
@@ -597,58 +628,67 @@ HTTP::Daemon - a simple http server class
 
 =head1 DESCRIPTION
 
-Instances of the I<HTTP::Daemon> class are HTTP/1.1 servers that
-listen on a socket for incoming requests. The I<HTTP::Daemon> is a
-sub-class of I<IO::Socket::INET>, so you can perform socket operations
+Instances of the C<HTTP::Daemon> class are HTTP/1.1 servers that
+listen on a socket for incoming requests. The C<HTTP::Daemon> is a
+subclass of C<IO::Socket::INET>, so you can perform socket operations
 directly on it too.
 
 The accept() method will return when a connection from a client is
-available.  In a scalar context the returned value will be a reference
-to a object of the I<HTTP::Daemon::ClientConn> class which is another
-I<IO::Socket::INET> subclass.  In a list context a two-element array
-is returned containing the new I<HTTP::Daemon::ClientConn> reference
-and the peer address; the list will be empty upon failure.  Calling
-the get_request() method on the I<HTTP::Daemon::ClientConn> object
-will read data from the client and return an I<HTTP::Request> object
-reference.
+available.  The returned value will be an C<HTTP::Daemon::ClientConn>
+object which is another C<IO::Socket::INET> subclass.  Calling the
+get_request() method on this object will read data from the client and
+return an C<HTTP::Request> object.  The ClientConn object also provide
+methods to send back various responses.
 
 This HTTP daemon does not fork(2) for you.  Your application, i.e. the
-user of the I<HTTP::Daemon> is reponsible for forking if that is
+user of the C<HTTP::Daemon> is responsible for forking if that is
 desirable.  Also note that the user is responsible for generating
-responses that conform to the HTTP/1.1 protocol.  The
-I<HTTP::Daemon::ClientConn> class provides some methods that make this easier.
+responses that conform to the HTTP/1.1 protocol.
 
-=head1 METHODS
-
-The following is a list of methods that are new (or enhanced) relative
-to the I<IO::Socket::INET> base class.
+The following methods of C<HTTP::Daemon> are new (or enhanced) relative
+to the C<IO::Socket::INET> base class:
 
 =over 4
 
-=item $d = new HTTP::Daemon
+=item $d = HTTP::Daemon->new
 
-The constructor takes the same parameters as the
-I<IO::Socket::INET> constructor.  It can also be called without specifying
-any parameters. The daemon will then set up a listen queue of 5
-connections and allocate some random port number.  A server that wants
-to bind to some specific address on the standard HTTP port will be
-constructed like this:
+=item $d = HTTP::Daemon->new( %opts )
 
-  $d = new HTTP::Daemon
-        LocalAddr => 'www.someplace.com',
-        LocalPort => 80;
+The constructor method takes the same arguments as the
+C<IO::Socket::INET> constructor, but unlike its base class it can also
+be called without any arguments.  The daemon will then set up a listen
+queue of 5 connections and allocate some random port number.
 
-=item $c = $d->accept([$pkg])
+A server that wants to bind to some specific address on the standard
+HTTP port will be constructed like this:
 
-This method is the same as I<IO::Socket::accept> but returns an
-I<HTTP::Daemon::ClientConn> reference by default.  It returns undef if
-you specify a timeout and no connection is made within that time.  In
-a scalar context the returned value will be a reference to a object of
-the I<HTTP::Daemon::ClientConn> class which is another
-I<IO::Socket::INET> subclass.  In a list context a two-element array
-is returned containing the new I<HTTP::Daemon::ClientConn> reference
-and the peer address; the list will be empty upon failure.
+  $d = HTTP::Daemon->new(
+           LocalAddr => 'www.thisplace.com',
+           LocalPort => 80,
+       );
 
+See L<IO::Socket::INET> for a description of other arguments that can
+be used configure the daemon during construction.
+
+=item $c = $d->accept
+
+=item $c = $d->accept( $pkg )
+
+=item ($c, $peer_addr) = $d->accept
+
+This method works the same the one provided by the base class, but it
+returns an C<HTTP::Daemon::ClientConn> reference by default.  If a
+package name is provided as argument, then the returned object will be
+blessed into the given class.  It is probably a good idea to make that
+class a subclass of C<HTTP::Daemon::ClientConn>.
+
+The accept method will return C<undef> if timeouts have been enabled
+and no connection is made within the given time.  The timeout() method
+is described in L<IO::Socket>.
+
+In list context both the client object and the peer address will be
+returned; see the description of the accept method L<IO::Socket> for
+details.
 
 =item $d->url
 
@@ -657,50 +697,52 @@ Returns a URL string that can be used to access the server root.
 =item $d->product_tokens
 
 Returns the name that this server will use to identify itself.  This
-is the string that is sent with the I<Server> response header.  The
+is the string that is sent with the C<Server> response header.  The
 main reason to have this method is that subclasses can override it if
 they want to use another product name.
 
+The default is the string "libwww-perl-daemon/#.##" where "#.##" is
+replaced with the version number of this module.
+
 =back
 
-The I<HTTP::Daemon::ClientConn> is also a I<IO::Socket::INET>
+The C<HTTP::Daemon::ClientConn> is a C<IO::Socket::INET>
 subclass. Instances of this class are returned by the accept() method
-of I<HTTP::Daemon>.  The following additional methods are
-provided:
+of C<HTTP::Daemon>.  The following methods are provided:
 
 =over 4
 
-=item $c->get_request([$headers_only])
+=item $c->get_request
 
-Read data from the client and turn it into an
-I<HTTP::Request> object which is then returned.  It returns C<undef>
-if reading of the request fails.  If it fails, then the
-I<HTTP::Daemon::ClientConn> object ($c) should be discarded, and you
-should not call this method again.  The $c->reason method might give
-you some information about why $c->get_request returned C<undef>.
+=item $c->get_request( $headers_only )
 
-The $c->get_request method supports HTTP/1.1 request content bodies,
-including I<chunked> transfer encoding with footer and self delimiting
-I<multipart/*> content types.
+This method read data from the client and turns it into an
+C<HTTP::Request> object which is returned.  It returns C<undef>
+if reading fails.  If it fails, then the C<HTTP::Daemon::ClientConn>
+object ($c) should be discarded, and you should not try call this
+method again on it.  The $c->reason method might give you some
+information about why $c->get_request failed.
 
-The $c->get_request method will normally not return until the whole
+The get_request() method will normally not return until the whole
 request has been received from the client.  This might not be what you
-want if the request is an upload of a multi-mega-byte file (and with
-chunked transfer encoding HTTP can even support infinite request
-messages - uploading live audio for instance).  If you pass a TRUE
-value as the $headers_only argument, then $c->get_request will return
-immediately after parsing the request headers and you are responsible
-for reading the rest of the request content.  If you are going to
-call $c->get_request again on the same connection you better read the
+want if the request is an upload of a large file (and with chunked
+transfer encoding HTTP can even support infinite request messages -
+uploading live audio for instance).  If you pass a TRUE value as the
+$headers_only argument, then get_request() will return immediately
+after parsing the request headers and you are responsible for reading
+the rest of the request content.  If you are going to call
+$c->get_request again on the same connection you better read the
 correct number of bytes.
 
-=item $c->read_buffer([$new_value])
+=item $c->read_buffer
+
+=item $c->read_buffer( $new_value )
 
 Bytes read by $c->get_request, but not used are placed in the I<read
 buffer>.  The next time $c->get_request is called it will consume the
 bytes in this buffer before reading more data from the network
 connection itself.  The read buffer is invalid after $c->get_request
-has returned an undefined value.
+has failed.
 
 If you handle the reading of the request content yourself you need to
 empty this buffer before you read more and you need to place
@@ -715,7 +757,7 @@ replace the buffer content if you pass it an argument.
 When $c->get_request returns C<undef> you can obtain a short string
 describing why it happened by calling $c->reason.
 
-=item $c->proto_ge($proto)
+=item $c->proto_ge( $proto )
 
 Return TRUE if the client announced a protocol with version number
 greater or equal to the given argument.  The $proto argument can be a
@@ -727,6 +769,11 @@ Return TRUE if the client speaks the HTTP/0.9 protocol.  No status
 code and no headers should be returned to such a client.  This should
 be the same as !$c->proto_ge("HTTP/1.0").
 
+=item $c->head_request
+
+Return TRUE if the last request was a C<HEAD> request.  No content
+body must be generated for these requests.
+
 =item $c->force_last_request
 
 Make sure that $c->get_request will not try to read more requests off
@@ -738,7 +785,13 @@ protocol HTTP/1.0 or worse and does not include a "Connection:
 Keep-Alive" header.  It is also turned on automatically when HTTP/1.1
 or better clients send the "Connection: close" request header.
 
-=item $c->send_status_line( [$code, [$mess, [$proto]]] )
+=item $c->send_status_line
+
+=item $c->send_status_line( $code )
+
+=item $c->send_status_line( $code, $mess )
+
+=item $c->send_status_line( $code, $mess, $proto )
 
 Send the status line back to the client.  If $code is omitted 200 is
 assumed.  If $mess is omitted, then a message corresponding to $code
@@ -749,39 +802,56 @@ $HTTP::Daemon::PROTO variable is used.
 
 Send the CRLF sequence to the client.
 
-=item $c->send_basic_header( [$code, [$mess, [$proto]]] )
+=item $c->send_basic_header
+
+=item $c->send_basic_header( $code )
+
+=item $c->send_basic_header( $code, $mess )
+
+=item $c->send_basic_header( $code, $mess, $proto )
 
 Send the status line and the "Date:" and "Server:" headers back to
 the client.  This header is assumed to be continued and does not end
 with an empty CRLF line.
 
-=item $c->send_response( [$res] )
+See the description of send_status_line() for the description of the
+accepted arguments.
 
-Write a I<HTTP::Response> object to the
+=item $c->send_response( $res )
+
+Write a C<HTTP::Response> object to the
 client as a response.  We try hard to make sure that the response is
 self delimiting so that the connection can stay persistent for further
 request/response exchanges.
 
-The content attribute of the I<HTTP::Response> object can be a normal
+The content attribute of the C<HTTP::Response> object can be a normal
 string or a subroutine reference.  If it is a subroutine, then
 whatever this callback routine returns is written back to the
 client as the response content.  The routine will be called until it
 return an undefined or empty value.  If the client is HTTP/1.1 aware
 then we will use chunked transfer encoding for the response.
 
-=item $c->send_redirect( $loc, [$code, [$entity_body]] )
+=item $c->send_redirect( $loc )
+
+=item $c->send_redirect( $loc, $code )
+
+=item $c->send_redirect( $loc, $code, $entity_body )
 
 Send a redirect response back to the client.  The location ($loc) can
 be an absolute or relative URL. The $code must be one the redirect
 status codes, and defaults to "301 Moved Permanently"
 
-=item $c->send_error( [$code, [$error_message]] )
+=item $c->send_error
+
+=item $c->send_error( $code )
+
+=item $c->send_error( $code, $error_message )
 
 Send an error response back to the client.  If the $code is missing a
 "Bad Request" error is reported.  The $error_message is a string that
 is incorporated in the body of the HTML entity body.
 
-=item $c->send_file_response($filename)
+=item $c->send_file_response( $filename )
 
 Send back a response with the specified $filename as content.  If the
 file is a directory we try to generate an HTML index of it.
@@ -791,24 +861,24 @@ file is a directory we try to generate an HTML index of it.
 =item $c->send_file( $fd )
 
 Copy the file to the client.  The file can be a string (which
-will be interpreted as a filename) or a reference to an I<IO::Handle>
+will be interpreted as a filename) or a reference to an C<IO::Handle>
 or glob.
 
 =item $c->daemon
 
-Return a reference to the corresponding I<HTTP::Daemon> object.
+Return a reference to the corresponding C<HTTP::Daemon> object.
 
 =back
 
 =head1 SEE ALSO
 
-RFC 2068
+RFC 2616
 
-L<IO::Socket::INET>, L<Apache>
+L<IO::Socket::INET>, L<IO::Socket>
 
 =head1 COPYRIGHT
 
-Copyright 1996-2001, Gisle Aas
+Copyright 1996-2003, Gisle Aas
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
